eventChannel property
The event channel used to receive audio device and route changes.
Implementation
@visibleForTesting
final eventChannel = const EventChannel('audio_output_picker/events');
The event channel used to receive audio device and route changes.
@visibleForTesting
final eventChannel = const EventChannel('audio_output_picker/events');