AudioInputDevice class
Represents an audio input / microphone device.
Constructors
- AudioInputDevice({required String id, required String name, required AudioInputType type, bool isSelected = false})
-
const
- AudioInputDevice.fromMap(Map? map)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Unique identifier of the input device.
final
- isExternal → bool
-
Whether this microphone is an external device.
no setter
- isSelected → bool
-
Whether this input device is currently active/selected.
final
- name → String
-
Human-readable name of the input device.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AudioInputType
-
Type category of the input device.
final
Methods
-
copyWith(
{String? id, String? name, AudioInputType? type, bool? isSelected}) → AudioInputDevice -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override