AudioOutputDevice class

Represents an audio output device.

Constructors

AudioOutputDevice({required String id, required String name, required AudioOutputType type, bool isSelected = false})
const
AudioOutputDevice.fromMap(Map? map)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier of the device.
final
isExternal bool
Whether this output is an external accessory.
no setter
isHeadphonesOrBluetooth bool
Whether this output is a headphone, earphone, bluetooth, or external accessory.
no setter
isSelected bool
Whether this device is currently the active/selected output.
final
name String
Human-readable name of the device.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AudioOutputType
Type category of the device.
final

Methods

copyWith({String? id, String? name, AudioOutputType? type, bool? isSelected}) AudioOutputDevice
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override