AudioOutputPickerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- AudioOutputPickerPlatform
- Implementers
Constructors
- AudioOutputPickerPlatform()
- Constructs a AudioOutputPickerPlatform.
Properties
-
audioDeviceEventStream
→ Stream<
Map< String, dynamic> > -
Stream of raw device / route change events from the native platform.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkBluetoothPermission(
) → Future< bool> - Checks if required bluetooth permissions (e.g. Bluetooth Connect on Android 12+) are granted.
-
checkMicrophonePermission(
) → Future< bool> - Checks if microphone recording permission is granted.
-
getAvailableAudioOutputs(
) → Future< List< AudioOutputDevice> > - Gets the list of available audio output devices.
-
getAvailableMicrophones(
) → Future< List< AudioInputDevice> > - Gets the list of available microphone / audio input devices.
-
getCurrentAudioOutput(
) → Future< AudioOutputDevice?> - Gets the currently active audio output device, or null if none/unknown.
-
getCurrentMicrophone(
) → Future< AudioInputDevice?> - Gets the currently active microphone / audio input device, or null if none/unknown.
-
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestBluetoothPermission(
) → Future< bool> - Requests required bluetooth permissions directly without 3rd party plugins.
-
requestMicrophonePermission(
) → Future< bool> - Requests microphone recording permission directly.
-
selectAudioOutput(
String deviceId) → Future< bool> -
Selects the audio output device with the given
deviceId. -
selectMicrophone(
String deviceId) → Future< bool> -
Selects the microphone / audio input device with the given
deviceId. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AudioOutputPickerPlatform
-
The default instance of AudioOutputPickerPlatform to use.
getter/setter pair